[gtksourceview/wip/chergert/minimap-cleanup] alter default opacity



commit 5a4aa0169351e45bc3860f23152c2d02c7742939
Author: Christian Hergert <christian hergert me>
Date:   Wed May 20 20:20:26 2015 -0700

    alter default opacity

 gtksourceview/gtksourcemap.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/gtksourceview/gtksourcemap.c b/gtksourceview/gtksourcemap.c
index 7d8bd04..5a52583 100644
--- a/gtksourceview/gtksourcemap.c
+++ b/gtksourceview/gtksourcemap.c
@@ -266,7 +266,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
         * any transformations.
         *
         * If the style scheme contains a "selection" style scheme, used for
         * selected text, we use that with a 0.45 alpha value.
         *
         * If none of these are met, we take the background from the
         * #GtkStyleContext using the deprecated
@@ -348,7 +348,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
                GdkRGBA color;
 
                gdk_rgba_parse (&color, background);
-               color.alpha = 0.45;
+               color.alpha = 0.75;
                g_free (background);
                background = gdk_rgba_to_string (&color);
        }
@@ -266,7 +266,7 @@ gtk_source_map_rebuild_css (GtkSourceMap *map)
         *
         * If the style scheme contains a "selection" style scheme, used for
-        * selected text, we use that with a 0.45 alpha value.
+        * selected text, we use that with a 0.75 alpha value.
         *
         * If none of these are met, we take the background from the


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]